# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: project.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'project.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import analysis_config_pb2 as analysis__config__pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  analysis__pb2 = analysis__config__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = analysis__config__pb2.analysis_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  analysis__version__pb2 = analysis__config__pb2.analysis__version__pb2
except AttributeError:
  analysis__version__pb2 = analysis__config__pb2.analysis_version_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  analysis__pb2 = analysis__config__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = analysis__config__pb2.analysis_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__version__pb2 = analysis__config__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = analysis__config__pb2.algorithm_version_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__pb2 = analysis__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = analysis__config__pb2.algorithm_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__config__pb2 = analysis__config__pb2.algorithm__config__pb2
except AttributeError:
  algorithm__config__pb2 = analysis__config__pb2.algorithm_config_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__pb2 = analysis__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = analysis__config__pb2.algorithm_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__version__pb2 = analysis__config__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = analysis__config__pb2.algorithm_version_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
try:
  algorithm__pb2 = analysis__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = analysis__config__pb2.algorithm_pb2
try:
  common__models__pb2 = analysis__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__config__pb2.common_models_pb2
from terrascope_api.models import analysis_computation_pb2 as analysis__computation__pb2
try:
  common__models__pb2 = analysis__computation__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__computation__pb2.common_models_pb2
try:
  analysis__pb2 = analysis__computation__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = analysis__computation__pb2.analysis_pb2
try:
  common__models__pb2 = analysis__computation__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__computation__pb2.common_models_pb2
from terrascope_api.models import aoi_collection_pb2 as aoi__collection__pb2
try:
  common__models__pb2 = aoi__collection__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = aoi__collection__pb2.common_models_pb2
from terrascope_api.models import result_pb2 as result__pb2
try:
  common__models__pb2 = result__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = result__pb2.common_models_pb2
try:
  toi__pb2 = result__pb2.toi__pb2
except AttributeError:
  toi__pb2 = result__pb2.toi_pb2
try:
  common__models__pb2 = result__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = result__pb2.common_models_pb2
from terrascope_api.models import project_filter_pb2 as project__filter__pb2
try:
  common__models__pb2 = project__filter__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__filter__pb2.common_models_pb2
try:
  filter__pb2 = project__filter__pb2.filter__pb2
except AttributeError:
  filter__pb2 = project__filter__pb2.filter_pb2
try:
  common__models__pb2 = project__filter__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__filter__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.analysis_config_pb2 import *
from terrascope_api.models.analysis_computation_pb2 import *
from terrascope_api.models.aoi_collection_pb2 import *
from terrascope_api.models.result_pb2 import *
from terrascope_api.models.project_filter_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rproject.proto\x12\x07oi.papi\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\x1a\x15\x61nalysis_config.proto\x1a\x1a\x61nalysis_computation.proto\x1a\x14\x61oi_collection.proto\x1a\x0cresult.proto\x1a\x14project_filter.proto\"\x9f\x06\n\x07Project\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07\x63reator\x18\x04 \x01(\t\x12.\n\x06status\x18\x05 \x01(\x0e\x32\x1e.oi.papi.Project.ProjectStatus\x12/\n\x0f\x61oi_collections\x18\x06 \x03(\x0b\x32\x16.oi.papi.AOICollection\x12;\n\x15\x61nalysis_computations\x18\x07 \x03(\x0b\x32\x1c.oi.papi.AnalysisComputation\x12\x31\n\x10\x61nalysis_configs\x18\x08 \x03(\x0b\x32\x17.oi.papi.AnalysisConfig\x12.\n\nstart_date\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_date\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_ts\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x11\x61vailable_filters\x18\x0c \x03(\x0b\x32\x16.oi.papi.ProjectFilter\x12/\n\x0f\x61pplied_filters\x18\r \x03(\x0b\x32\x16.oi.papi.ProjectFilter\x12/\n\x0btime_ranges\x18\x0e \x03(\x0b\x32\x1a.oi.papi.Project.TimeRange\x12\x0c\n\x04type\x18\x0f \x01(\t\x1a_\n\tTimeRange\x12)\n\x05start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"q\n\rProjectStatus\x12\x1a\n\x16UNKNOWN_PROJECT_STATUS\x10\x00\x12\r\n\tCOMPLETED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0b\n\x07STOPPED\x10\x03\x12\x0f\n\x0bNOT_STARTED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\"=\n\x12ProjectListRequest\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\"w\n\x13ProjectListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\"\n\x08projects\x18\x02 \x03(\x0b\x32\x10.oi.papi.Project\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x1f\n\x11ProjectGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\"L\n\x12ProjectGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12!\n\x07project\x18\x02 \x01(\x0b\x32\x10.oi.papi.Project\"9\n\x14ProjectCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"O\n\x15ProjectCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12!\n\x07project\x18\x02 \x01(\x0b\x32\x10.oi.papi.Project\":\n\x14ProjectUpdateRequest\x12\"\n\x08projects\x18\x01 \x03(\x0b\x32\x10.oi.papi.Project\",\n\x15ProjectUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"#\n\x14ProjectDeleteRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\",\n\x15ProjectDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\" \n\x11ProjectRunRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\")\n\x12ProjectRunResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"!\n\x13ProjectCloneRequest\x12\n\n\x02id\x18\x01 \x01(\t\"N\n\x14ProjectCloneResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12!\n\x07project\x18\x02 \x01(\x0b\x32\x10.oi.papi.Project\"2\n\x1cProjectCreditEstimateRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"\x88\x01\n\x1dProjectCreditEstimateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x17\n\x0f\x61pplied_credits\x18\x02 \x01(\x01\x12\x13\n\x0bnew_credits\x18\x03 \x01(\x01\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x13\n\x0bis_runnable\x18\x05 \x01(\x08\"1\n\x1bProjectRequestAccessRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"3\n\x1cProjectRequestAccessResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xb1\x05\n\nProjectApi\x12\x41\n\x04list\x12\x1b.oi.papi.ProjectListRequest\x1a\x1c.oi.papi.ProjectListResponse\x12>\n\x03get\x12\x1a.oi.papi.ProjectGetRequest\x1a\x1b.oi.papi.ProjectGetResponse\x12G\n\x06\x63reate\x12\x1d.oi.papi.ProjectCreateRequest\x1a\x1e.oi.papi.ProjectCreateResponse\x12G\n\x06update\x12\x1d.oi.papi.ProjectUpdateRequest\x1a\x1e.oi.papi.ProjectUpdateResponse\x12G\n\x06\x64\x65lete\x12\x1d.oi.papi.ProjectDeleteRequest\x1a\x1e.oi.papi.ProjectDeleteResponse\x12>\n\x03run\x12\x1a.oi.papi.ProjectRunRequest\x1a\x1b.oi.papi.ProjectRunResponse\x12\x44\n\x05\x63lone\x12\x1c.oi.papi.ProjectCloneRequest\x1a\x1d.oi.papi.ProjectCloneResponse\x12`\n\x0f\x63redit_estimate\x12%.oi.papi.ProjectCreditEstimateRequest\x1a&.oi.papi.ProjectCreditEstimateResponse\x12]\n\x0erequest_access\x12$.oi.papi.ProjectRequestAccessRequest\x1a%.oi.papi.ProjectRequestAccessResponseP\x01P\x02P\x03P\x04P\x05P\x06\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'project_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PROJECT']._serialized_start=190
  _globals['_PROJECT']._serialized_end=989
  _globals['_PROJECT_TIMERANGE']._serialized_start=779
  _globals['_PROJECT_TIMERANGE']._serialized_end=874
  _globals['_PROJECT_PROJECTSTATUS']._serialized_start=876
  _globals['_PROJECT_PROJECTSTATUS']._serialized_end=989
  _globals['_PROJECTLISTREQUEST']._serialized_start=991
  _globals['_PROJECTLISTREQUEST']._serialized_end=1052
  _globals['_PROJECTLISTRESPONSE']._serialized_start=1054
  _globals['_PROJECTLISTRESPONSE']._serialized_end=1173
  _globals['_PROJECTGETREQUEST']._serialized_start=1175
  _globals['_PROJECTGETREQUEST']._serialized_end=1206
  _globals['_PROJECTGETRESPONSE']._serialized_start=1208
  _globals['_PROJECTGETRESPONSE']._serialized_end=1284
  _globals['_PROJECTCREATEREQUEST']._serialized_start=1286
  _globals['_PROJECTCREATEREQUEST']._serialized_end=1343
  _globals['_PROJECTCREATERESPONSE']._serialized_start=1345
  _globals['_PROJECTCREATERESPONSE']._serialized_end=1424
  _globals['_PROJECTUPDATEREQUEST']._serialized_start=1426
  _globals['_PROJECTUPDATEREQUEST']._serialized_end=1484
  _globals['_PROJECTUPDATERESPONSE']._serialized_start=1486
  _globals['_PROJECTUPDATERESPONSE']._serialized_end=1530
  _globals['_PROJECTDELETEREQUEST']._serialized_start=1532
  _globals['_PROJECTDELETEREQUEST']._serialized_end=1567
  _globals['_PROJECTDELETERESPONSE']._serialized_start=1569
  _globals['_PROJECTDELETERESPONSE']._serialized_end=1613
  _globals['_PROJECTRUNREQUEST']._serialized_start=1615
  _globals['_PROJECTRUNREQUEST']._serialized_end=1647
  _globals['_PROJECTRUNRESPONSE']._serialized_start=1649
  _globals['_PROJECTRUNRESPONSE']._serialized_end=1690
  _globals['_PROJECTCLONEREQUEST']._serialized_start=1692
  _globals['_PROJECTCLONEREQUEST']._serialized_end=1725
  _globals['_PROJECTCLONERESPONSE']._serialized_start=1727
  _globals['_PROJECTCLONERESPONSE']._serialized_end=1805
  _globals['_PROJECTCREDITESTIMATEREQUEST']._serialized_start=1807
  _globals['_PROJECTCREDITESTIMATEREQUEST']._serialized_end=1857
  _globals['_PROJECTCREDITESTIMATERESPONSE']._serialized_start=1860
  _globals['_PROJECTCREDITESTIMATERESPONSE']._serialized_end=1996
  _globals['_PROJECTREQUESTACCESSREQUEST']._serialized_start=1998
  _globals['_PROJECTREQUESTACCESSREQUEST']._serialized_end=2047
  _globals['_PROJECTREQUESTACCESSRESPONSE']._serialized_start=2049
  _globals['_PROJECTREQUESTACCESSRESPONSE']._serialized_end=2100
  _globals['_PROJECTAPI']._serialized_start=2103
  _globals['_PROJECTAPI']._serialized_end=2792
# @@protoc_insertion_point(module_scope)
