# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: order_recommendation.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'order_recommendation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aorder_recommendation.proto\x12\x07oi.papi\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcd\x01\n\x13OrderRecommendation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\x12\x15\n\rjustification\x18\x03 \x01(\t\x12\x0c\n\x04team\x18\x04 \x01(\t\x12\x14\n\x0c\x63ontact_info\x18\x05 \x01(\t\x12.\n\nexpiration\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_on\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9f\x01\n OrderRecommendationCreateRequest\x12\x10\n\x08order_id\x18\x02 \x01(\t\x12\x15\n\rjustification\x18\x03 \x01(\t\x12\x0c\n\x04team\x18\x04 \x01(\t\x12\x14\n\x0c\x63ontact_info\x18\x05 \x01(\t\x12.\n\nexpiration\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"t\n!OrderRecommendationCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12:\n\x14order_recommendation\x18\x02 \x01(\x0b\x32\x1c.oi.papi.OrderRecommendation\"\xae\x01\n OrderRecommendationUpdateRequest\x12\x1f\n\x17order_recommendation_id\x18\x01 \x01(\t\x12\x15\n\rjustification\x18\x02 \x01(\t\x12\x0c\n\x04team\x18\x03 \x01(\t\x12\x14\n\x0c\x63ontact_info\x18\x04 \x01(\t\x12.\n\nexpiration\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"t\n!OrderRecommendationUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12:\n\x14order_recommendation\x18\x02 \x01(\x0b\x32\x1c.oi.papi.OrderRecommendation\"C\n OrderRecommendationDeleteRequest\x12\x1f\n\x17order_recommendation_id\x18\x01 \x01(\t\"8\n!OrderRecommendationDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xbb\x02\n\x16OrderRecommendationApi\x12_\n\x06\x63reate\x12).oi.papi.OrderRecommendationCreateRequest\x1a*.oi.papi.OrderRecommendationCreateResponse\x12_\n\x06update\x12).oi.papi.OrderRecommendationUpdateRequest\x1a*.oi.papi.OrderRecommendationUpdateResponse\x12_\n\x06\x64\x65lete\x12).oi.papi.OrderRecommendationDeleteRequest\x1a*.oi.papi.OrderRecommendationDeleteResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'order_recommendation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ORDERRECOMMENDATION']._serialized_start=73
  _globals['_ORDERRECOMMENDATION']._serialized_end=278
  _globals['_ORDERRECOMMENDATIONCREATEREQUEST']._serialized_start=281
  _globals['_ORDERRECOMMENDATIONCREATEREQUEST']._serialized_end=440
  _globals['_ORDERRECOMMENDATIONCREATERESPONSE']._serialized_start=442
  _globals['_ORDERRECOMMENDATIONCREATERESPONSE']._serialized_end=558
  _globals['_ORDERRECOMMENDATIONUPDATEREQUEST']._serialized_start=561
  _globals['_ORDERRECOMMENDATIONUPDATEREQUEST']._serialized_end=735
  _globals['_ORDERRECOMMENDATIONUPDATERESPONSE']._serialized_start=737
  _globals['_ORDERRECOMMENDATIONUPDATERESPONSE']._serialized_end=853
  _globals['_ORDERRECOMMENDATIONDELETEREQUEST']._serialized_start=855
  _globals['_ORDERRECOMMENDATIONDELETEREQUEST']._serialized_end=922
  _globals['_ORDERRECOMMENDATIONDELETERESPONSE']._serialized_start=924
  _globals['_ORDERRECOMMENDATIONDELETERESPONSE']._serialized_end=980
  _globals['_ORDERRECOMMENDATIONAPI']._serialized_start=983
  _globals['_ORDERRECOMMENDATIONAPI']._serialized_end=1298
# @@protoc_insertion_point(module_scope)
