# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tasking_order.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'tasking_order.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import order_recommendation_pb2 as order__recommendation__pb2
from terrascope_api.models import order_pb2 as order__pb2
try:
  order__recommendation__pb2 = order__pb2.order__recommendation__pb2
except AttributeError:
  order__recommendation__pb2 = order__pb2.order_recommendation_pb2

from terrascope_api.models.order_recommendation_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13tasking_order.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1aorder_recommendation.proto\x1a\x0border.proto\"j\n\tTimeRange\x12-\n\tstart_utc\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nfinish_utc\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xce\x03\n\x0cTaskingOrder\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x61ta_source_id\x18\x02 \x01(\t\x12\x13\n\x0btarget_geom\x18\x03 \x01(\x0c\x12&\n\nacq_window\x18\x04 \x01(\x0b\x32\x12.oi.papi.TimeRange\x12\x19\n\x11product_spec_name\x18\x05 \x01(\t\x12\"\n\x05state\x18\x06 \x01(\x0e\x32\x13.oi.papi.OrderState\x12\x0f\n\x07\x64\x65tails\x18\x07 \x01(\t\x12\x0b\n\x03url\x18\x08 \x01(\t\x12)\n\x08metadata\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07\x63reator\x18\n \x01(\t\x12.\n\ncreated_on\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_on\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x61pproved_by\x18\r \x01(\t\x12\x18\n\x10\x61pproval_comment\x18\x0e \x01(\t\x12\x35\n\x0frecommendations\x18\x0f \x03(\x0b\x32\x1c.oi.papi.OrderRecommendation\"\x9c\x01\n\x17TaskingOrderListRequest\x12#\n\x06states\x18\x01 \x03(\x0e\x32\x13.oi.papi.OrderState\x12\x17\n\x0f\x64\x61ta_source_ids\x18\x02 \x03(\t\x12 \n\x18\x61nalysis_computation_ids\x18\x03 \x03(\t\x12!\n\x19\x61lgorithm_computation_ids\x18\x04 \x03(\t\"V\n\x18TaskingOrderListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12%\n\x06orders\x18\x02 \x03(\x0b\x32\x15.oi.papi.TaskingOrder\"$\n\x16TaskingOrderGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\"T\n\x17TaskingOrderGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12$\n\x05order\x18\x02 \x01(\x0b\x32\x15.oi.papi.TaskingOrder\"9\n\x1aTaskingOrderApproveRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07\x63omment\x18\x02 \x01(\t\"2\n\x1bTaskingOrderApproveResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"\xb6\x01\n\x19TaskingOrderCreateRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x19\n\x11product_spec_name\x18\x02 \x01(\t\x12\x13\n\x0btarget_geom\x18\x03 \x01(\x0c\x12&\n\nacq_window\x18\x04 \x01(\x0b\x32\x12.oi.papi.TimeRange\x12)\n\x08metadata\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"W\n\x1aTaskingOrderCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12$\n\x05order\x18\x02 \x01(\x0b\x32\x15.oi.papi.TaskingOrder\"\'\n\x19TaskingOrderCancelRequest\x12\n\n\x02id\x18\x01 \x01(\t\"1\n\x1aTaskingOrderCancelResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xa4\x03\n\x0fTaskingOrderApi\x12K\n\x04list\x12 .oi.papi.TaskingOrderListRequest\x1a!.oi.papi.TaskingOrderListResponse\x12H\n\x03get\x12\x1f.oi.papi.TaskingOrderGetRequest\x1a .oi.papi.TaskingOrderGetResponse\x12Q\n\x06\x63reate\x12\".oi.papi.TaskingOrderCreateRequest\x1a#.oi.papi.TaskingOrderCreateResponse\x12T\n\x07\x61pprove\x12#.oi.papi.TaskingOrderApproveRequest\x1a$.oi.papi.TaskingOrderApproveResponse\x12Q\n\x06\x63\x61ncel\x12\".oi.papi.TaskingOrderCancelRequest\x1a#.oi.papi.TaskingOrderCancelResponseP\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tasking_order_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TIMERANGE']._serialized_start=136
  _globals['_TIMERANGE']._serialized_end=242
  _globals['_TASKINGORDER']._serialized_start=245
  _globals['_TASKINGORDER']._serialized_end=707
  _globals['_TASKINGORDERLISTREQUEST']._serialized_start=710
  _globals['_TASKINGORDERLISTREQUEST']._serialized_end=866
  _globals['_TASKINGORDERLISTRESPONSE']._serialized_start=868
  _globals['_TASKINGORDERLISTRESPONSE']._serialized_end=954
  _globals['_TASKINGORDERGETREQUEST']._serialized_start=956
  _globals['_TASKINGORDERGETREQUEST']._serialized_end=992
  _globals['_TASKINGORDERGETRESPONSE']._serialized_start=994
  _globals['_TASKINGORDERGETRESPONSE']._serialized_end=1078
  _globals['_TASKINGORDERAPPROVEREQUEST']._serialized_start=1080
  _globals['_TASKINGORDERAPPROVEREQUEST']._serialized_end=1137
  _globals['_TASKINGORDERAPPROVERESPONSE']._serialized_start=1139
  _globals['_TASKINGORDERAPPROVERESPONSE']._serialized_end=1189
  _globals['_TASKINGORDERCREATEREQUEST']._serialized_start=1192
  _globals['_TASKINGORDERCREATEREQUEST']._serialized_end=1374
  _globals['_TASKINGORDERCREATERESPONSE']._serialized_start=1376
  _globals['_TASKINGORDERCREATERESPONSE']._serialized_end=1463
  _globals['_TASKINGORDERCANCELREQUEST']._serialized_start=1465
  _globals['_TASKINGORDERCANCELREQUEST']._serialized_end=1504
  _globals['_TASKINGORDERCANCELRESPONSE']._serialized_start=1506
  _globals['_TASKINGORDERCANCELRESPONSE']._serialized_end=1555
  _globals['_TASKINGORDERAPI']._serialized_start=1558
  _globals['_TASKINGORDERAPI']._serialized_end=1978
# @@protoc_insertion_point(module_scope)
