# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: project_result.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'project_result.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import result_pb2 as result__pb2
try:
  common__models__pb2 = result__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = result__pb2.common_models_pb2
try:
  toi__pb2 = result__pb2.toi__pb2
except AttributeError:
  toi__pb2 = result__pb2.toi_pb2
try:
  common__models__pb2 = result__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = result__pb2.common_models_pb2
from terrascope_api.models import analysis_pb2 as analysis__pb2
try:
  common__models__pb2 = analysis__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = analysis__pb2.common_models_pb2
from terrascope_api.models import algorithm_config_pb2 as algorithm__config__pb2
try:
  common__models__pb2 = algorithm__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__config__pb2.common_models_pb2
try:
  algorithm__pb2 = algorithm__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = algorithm__config__pb2.algorithm_pb2
try:
  common__models__pb2 = algorithm__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__config__pb2.common_models_pb2
try:
  algorithm__version__pb2 = algorithm__config__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = algorithm__config__pb2.algorithm_version_pb2
try:
  common__models__pb2 = algorithm__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__config__pb2.common_models_pb2
try:
  algorithm__pb2 = algorithm__config__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = algorithm__config__pb2.algorithm_pb2
try:
  common__models__pb2 = algorithm__config__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = algorithm__config__pb2.common_models_pb2
from terrascope_api.models import visualization_pb2 as visualization__pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.result_pb2 import *
from terrascope_api.models.analysis_pb2 import *
from terrascope_api.models.algorithm_config_pb2 import *
from terrascope_api.models.visualization_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14project_result.proto\x12\x07oi.papi\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\x1a\x0cresult.proto\x1a\x0e\x61nalysis.proto\x1a\x16\x61lgorithm_config.proto\x1a\x13visualization.proto\"\x82\x02\n\x13ProjectResultStatus\x12\x1a\n\x12\x61nalysis_config_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61oi_id\x18\x02 \x01(\t\x12M\n\x10result_indicator\x18\x03 \x01(\x0e\x32\x33.oi.papi.ProjectResultStatus.ProjectResultIndicator\"p\n\x16ProjectResultIndicator\x12\x19\n\x15UNKNOWN_RESULT_STATUS\x10\x00\x12\x0f\n\x0bNOT_STARTED\x10\x01\x12\x0f\n\x0bIN_PROGRESS\x10\x02\x12\r\n\tAVAILABLE\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\"\xf5\x02\n\x1aProjectResultDownloadInput\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x38\n\x14observation_start_ts\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12observation_end_ts\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12T\n\tfile_type\x18\x04 \x01(\x0e\x32\x41.oi.papi.ProjectResultDownloadInput.ProjectResultDownloadFileType\x12\x11\n\tdata_type\x18\x05 \x01(\t\"h\n\x1dProjectResultDownloadFileType\x12\x15\n\x11UNKNOWN_FILE_TYPE\x10\x00\x12\x07\n\x03\x43SV\x10\x01\x12\r\n\tSHAPEFILE\x10\x02\x12\x0b\n\x07GEOJSON\x10\x03\x12\x0b\n\x07PARQUET\x10\x04\"\xfb\x02\n\x1bProjectResultDownloadOutput\x12\x14\n\x0c\x64ownload_url\x18\x01 \x01(\t\x12Y\n\x0f\x64ownload_status\x18\x02 \x01(\x0e\x32@.oi.papi.ProjectResultDownloadOutput.ProjectResultDownloadStatus\x12.\n\ncreated_ts\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x66ile_size_bytes\x18\x04 \x01(\r\x12;\n\x0e\x64ownload_input\x18\x05 \x01(\x0b\x32#.oi.papi.ProjectResultDownloadInput\"e\n\x1bProjectResultDownloadStatus\x12\x1b\n\x17UNKNOWN_DOWNLOAD_STATUS\x10\x00\x12\x0e\n\nPROCESSING\x10\x01\x12\r\n\tSUCCEEDED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\"\xbd\x01\n\rProjectResult\x12\x37\n\x13result_get_response\x18\x01 \x01(\x0b\x32\x1a.oi.papi.ResultGetResponse\x12?\n\x17\x61nalysis_algorithm_node\x18\x02 \x01(\x0b\x32\x1e.oi.papi.AnalysisAlgorithmNode\x12\x32\n\x10\x61lgorithm_config\x18\x03 \x01(\x0b\x32\x18.oi.papi.AlgorithmConfig\"\xf1\x01\n\x17ProjectResultGetRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x1a\n\x12\x61nalysis_config_id\x18\x02 \x01(\t\x12\x1a\n\x12source_aoi_version\x18\x03 \x01(\r\x12I\n\x0fvisualizer_type\x18\x04 \x01(\x0e\x32\x30.oi.papi.visualization.Visualizer.VisualizerType\x12\x1c\n\x14include_export_files\x18\x05 \x01(\x08\x12!\n\x19include_measurement_files\x18\x06 \x01(\x08\"`\n\x18ProjectResultGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12/\n\x0fproject_results\x18\x02 \x03(\x0b\x32\x16.oi.papi.ProjectResult\"3\n\x1dProjectResultGetStatusRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"\xef\x01\n\x1eProjectResultGetStatusResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x34\n\x0eresults_status\x18\x02 \x03(\x0b\x32\x1c.oi.papi.ProjectResultStatus\x12\x42\n\x08progress\x18\x03 \x01(\x0b\x32\x30.oi.papi.ProjectResultGetStatusResponse.Progress\x1a>\n\x08Progress\x12\x0f\n\x07running\x18\x01 \x01(\x01\x12\x11\n\tsucceeded\x18\x02 \x01(\x01\x12\x0e\n\x06\x66\x61iled\x18\x03 \x01(\x01\"^\n\x1fProjectResultGetDownloadRequest\x12;\n\x0e\x64ownload_input\x18\x01 \x01(\x0b\x32#.oi.papi.ProjectResultDownloadInput\"w\n ProjectResultGetDownloadResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12>\n\x10\x64ownload_outputs\x18\x02 \x03(\x0b\x32$.oi.papi.ProjectResultDownloadOutput\"c\n$ProjectResultGenerateDownloadRequest\x12;\n\x0e\x64ownload_input\x18\x01 \x01(\x0b\x32#.oi.papi.ProjectResultDownloadInput\"<\n%ProjectResultGenerateDownloadResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\x96\x03\n\x10ProjectResultApi\x12J\n\x03get\x12 .oi.papi.ProjectResultGetRequest\x1a!.oi.papi.ProjectResultGetResponse\x12]\n\nget_status\x12&.oi.papi.ProjectResultGetStatusRequest\x1a\'.oi.papi.ProjectResultGetStatusResponse\x12\x63\n\x0cget_download\x12(.oi.papi.ProjectResultGetDownloadRequest\x1a).oi.papi.ProjectResultGetDownloadResponse\x12r\n\x11generate_download\x12-.oi.papi.ProjectResultGenerateDownloadRequest\x1a..oi.papi.ProjectResultGenerateDownloadResponseP\x01P\x02P\x03P\x04P\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'project_result_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PROJECTRESULTSTATUS']._serialized_start=163
  _globals['_PROJECTRESULTSTATUS']._serialized_end=421
  _globals['_PROJECTRESULTSTATUS_PROJECTRESULTINDICATOR']._serialized_start=309
  _globals['_PROJECTRESULTSTATUS_PROJECTRESULTINDICATOR']._serialized_end=421
  _globals['_PROJECTRESULTDOWNLOADINPUT']._serialized_start=424
  _globals['_PROJECTRESULTDOWNLOADINPUT']._serialized_end=797
  _globals['_PROJECTRESULTDOWNLOADINPUT_PROJECTRESULTDOWNLOADFILETYPE']._serialized_start=693
  _globals['_PROJECTRESULTDOWNLOADINPUT_PROJECTRESULTDOWNLOADFILETYPE']._serialized_end=797
  _globals['_PROJECTRESULTDOWNLOADOUTPUT']._serialized_start=800
  _globals['_PROJECTRESULTDOWNLOADOUTPUT']._serialized_end=1179
  _globals['_PROJECTRESULTDOWNLOADOUTPUT_PROJECTRESULTDOWNLOADSTATUS']._serialized_start=1078
  _globals['_PROJECTRESULTDOWNLOADOUTPUT_PROJECTRESULTDOWNLOADSTATUS']._serialized_end=1179
  _globals['_PROJECTRESULT']._serialized_start=1182
  _globals['_PROJECTRESULT']._serialized_end=1371
  _globals['_PROJECTRESULTGETREQUEST']._serialized_start=1374
  _globals['_PROJECTRESULTGETREQUEST']._serialized_end=1615
  _globals['_PROJECTRESULTGETRESPONSE']._serialized_start=1617
  _globals['_PROJECTRESULTGETRESPONSE']._serialized_end=1713
  _globals['_PROJECTRESULTGETSTATUSREQUEST']._serialized_start=1715
  _globals['_PROJECTRESULTGETSTATUSREQUEST']._serialized_end=1766
  _globals['_PROJECTRESULTGETSTATUSRESPONSE']._serialized_start=1769
  _globals['_PROJECTRESULTGETSTATUSRESPONSE']._serialized_end=2008
  _globals['_PROJECTRESULTGETSTATUSRESPONSE_PROGRESS']._serialized_start=1946
  _globals['_PROJECTRESULTGETSTATUSRESPONSE_PROGRESS']._serialized_end=2008
  _globals['_PROJECTRESULTGETDOWNLOADREQUEST']._serialized_start=2010
  _globals['_PROJECTRESULTGETDOWNLOADREQUEST']._serialized_end=2104
  _globals['_PROJECTRESULTGETDOWNLOADRESPONSE']._serialized_start=2106
  _globals['_PROJECTRESULTGETDOWNLOADRESPONSE']._serialized_end=2225
  _globals['_PROJECTRESULTGENERATEDOWNLOADREQUEST']._serialized_start=2227
  _globals['_PROJECTRESULTGENERATEDOWNLOADREQUEST']._serialized_end=2326
  _globals['_PROJECTRESULTGENERATEDOWNLOADRESPONSE']._serialized_start=2328
  _globals['_PROJECTRESULTGENERATEDOWNLOADRESPONSE']._serialized_end=2388
  _globals['_PROJECTRESULTAPI']._serialized_start=2391
  _globals['_PROJECTRESULTAPI']._serialized_end=2797
# @@protoc_insertion_point(module_scope)
