# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: user.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nuser.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\"/\n\x0cLoginRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"7\n\rLoginResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x11\n\tjwt_token\x18\x02 \x01(\t\"G\n\x19UserChangePasswordRequest\x12\x14\n\x0cold_password\x18\x01 \x01(\t\x12\x14\n\x0cnew_password\x18\x02 \x01(\t\"1\n\x1aUserChangePasswordResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"5\n\x1fUserGenerateTempPasswordRequest\x12\x12\n\nuser_email\x18\x01 \x01(\t\"M\n UserGenerateTempPasswordResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x14\n\x0cnew_password\x18\x02 \x01(\t\"L\n\x04User\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x1b\n\x13user_collection_ids\x18\x04 \x03(\t\"L\n\x11UserCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x1a\n\x12user_collection_id\x18\x03 \x01(\t\"F\n\x12UserCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1b\n\x04user\x18\x02 \x01(\x0b\x32\r.oi.papi.User\"0\n\x11UserUpdateRequest\x12\x1b\n\x04user\x18\x01 \x01(\x0b\x32\r.oi.papi.User\")\n\x12UserUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"$\n\x11UserDeleteRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\")\n\x12UserDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"-\n\x0eUserGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\x0e\n\x06\x65mails\x18\x02 \x03(\t\"D\n\x0fUserGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1c\n\x05users\x18\x02 \x03(\x0b\x32\r.oi.papi.User\" \n\x0fUserListRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"E\n\x10UserListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1c\n\x05users\x18\x02 \x03(\x0b\x32\r.oi.papi.User\"*\n\x0cKeyValuePair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x1a\n\x18UserPropertiesGetRequest\"[\n\x19UserPropertiesGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12)\n\nproperties\x18\x02 \x03(\x0b\x32\x15.oi.papi.KeyValuePair\"]\n\x1bUserPropertiesUpdateRequest\x12)\n\nproperties\x18\x01 \x03(\x0b\x32\x15.oi.papi.KeyValuePair\x12\x13\n\x0breplace_all\x18\x02 \x01(\x08\"3\n\x1cUserPropertiesUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"\x16\n\x14UserPublicKeyRequest\"=\n\x15UserPublicKeyResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x0f\n\x07key_pem\x18\x02 \x01(\t2\xd8\x06\n\x07UserApi\x12\x36\n\x05login\x12\x15.oi.papi.LoginRequest\x1a\x16.oi.papi.LoginResponse\x12Z\n\x0f\x63hange_password\x12\".oi.papi.UserChangePasswordRequest\x1a#.oi.papi.UserChangePasswordResponse\x12m\n\x16generate_temp_password\x12(.oi.papi.UserGenerateTempPasswordRequest\x1a).oi.papi.UserGenerateTempPasswordResponse\x12\x41\n\x06\x63reate\x12\x1a.oi.papi.UserCreateRequest\x1a\x1b.oi.papi.UserCreateResponse\x12\x38\n\x03get\x12\x17.oi.papi.UserGetRequest\x1a\x18.oi.papi.UserGetResponse\x12\x41\n\x06update\x12\x1a.oi.papi.UserUpdateRequest\x1a\x1b.oi.papi.UserUpdateResponse\x12\x41\n\x06\x64\x65lete\x12\x1a.oi.papi.UserDeleteRequest\x1a\x1b.oi.papi.UserDeleteResponse\x12;\n\x04list\x12\x18.oi.papi.UserListRequest\x1a\x19.oi.papi.UserListResponse\x12W\n\x0eget_properties\x12!.oi.papi.UserPropertiesGetRequest\x1a\".oi.papi.UserPropertiesGetResponse\x12`\n\x11update_properties\x12$.oi.papi.UserPropertiesUpdateRequest\x1a%.oi.papi.UserPropertiesUpdateResponse\x12O\n\x0eget_public_key\x12\x1d.oi.papi.UserPublicKeyRequest\x1a\x1e.oi.papi.UserPublicKeyResponseP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LOGINREQUEST']._serialized_start=44
  _globals['_LOGINREQUEST']._serialized_end=91
  _globals['_LOGINRESPONSE']._serialized_start=93
  _globals['_LOGINRESPONSE']._serialized_end=148
  _globals['_USERCHANGEPASSWORDREQUEST']._serialized_start=150
  _globals['_USERCHANGEPASSWORDREQUEST']._serialized_end=221
  _globals['_USERCHANGEPASSWORDRESPONSE']._serialized_start=223
  _globals['_USERCHANGEPASSWORDRESPONSE']._serialized_end=272
  _globals['_USERGENERATETEMPPASSWORDREQUEST']._serialized_start=274
  _globals['_USERGENERATETEMPPASSWORDREQUEST']._serialized_end=327
  _globals['_USERGENERATETEMPPASSWORDRESPONSE']._serialized_start=329
  _globals['_USERGENERATETEMPPASSWORDRESPONSE']._serialized_end=406
  _globals['_USER']._serialized_start=408
  _globals['_USER']._serialized_end=484
  _globals['_USERCREATEREQUEST']._serialized_start=486
  _globals['_USERCREATEREQUEST']._serialized_end=562
  _globals['_USERCREATERESPONSE']._serialized_start=564
  _globals['_USERCREATERESPONSE']._serialized_end=634
  _globals['_USERUPDATEREQUEST']._serialized_start=636
  _globals['_USERUPDATEREQUEST']._serialized_end=684
  _globals['_USERUPDATERESPONSE']._serialized_start=686
  _globals['_USERUPDATERESPONSE']._serialized_end=727
  _globals['_USERDELETEREQUEST']._serialized_start=729
  _globals['_USERDELETEREQUEST']._serialized_end=765
  _globals['_USERDELETERESPONSE']._serialized_start=767
  _globals['_USERDELETERESPONSE']._serialized_end=808
  _globals['_USERGETREQUEST']._serialized_start=810
  _globals['_USERGETREQUEST']._serialized_end=855
  _globals['_USERGETRESPONSE']._serialized_start=857
  _globals['_USERGETRESPONSE']._serialized_end=925
  _globals['_USERLISTREQUEST']._serialized_start=927
  _globals['_USERLISTREQUEST']._serialized_end=959
  _globals['_USERLISTRESPONSE']._serialized_start=961
  _globals['_USERLISTRESPONSE']._serialized_end=1030
  _globals['_KEYVALUEPAIR']._serialized_start=1032
  _globals['_KEYVALUEPAIR']._serialized_end=1074
  _globals['_USERPROPERTIESGETREQUEST']._serialized_start=1076
  _globals['_USERPROPERTIESGETREQUEST']._serialized_end=1102
  _globals['_USERPROPERTIESGETRESPONSE']._serialized_start=1104
  _globals['_USERPROPERTIESGETRESPONSE']._serialized_end=1195
  _globals['_USERPROPERTIESUPDATEREQUEST']._serialized_start=1197
  _globals['_USERPROPERTIESUPDATEREQUEST']._serialized_end=1290
  _globals['_USERPROPERTIESUPDATERESPONSE']._serialized_start=1292
  _globals['_USERPROPERTIESUPDATERESPONSE']._serialized_end=1343
  _globals['_USERPUBLICKEYREQUEST']._serialized_start=1345
  _globals['_USERPUBLICKEYREQUEST']._serialized_end=1367
  _globals['_USERPUBLICKEYRESPONSE']._serialized_start=1369
  _globals['_USERPUBLICKEYRESPONSE']._serialized_end=1430
  _globals['_USERAPI']._serialized_start=1433
  _globals['_USERAPI']._serialized_end=2289
# @@protoc_insertion_point(module_scope)
