# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: algorithm_manifest.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'algorithm_manifest.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61lgorithm_manifest.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x13\x63ommon_models.proto\"4\n!AlgorithmManifestSchemaGetRequest\x12\x0f\n\x07version\x18\x01 \x01(\t\"s\n\"AlgorithmManifestSchemaGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\'\n\x06schema\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct2v\n\x14\x41lgorithmManifestApi\x12^\n\x03get\x12*.oi.papi.AlgorithmManifestSchemaGetRequest\x1a+.oi.papi.AlgorithmManifestSchemaGetResponseP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'algorithm_manifest_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ALGORITHMMANIFESTSCHEMAGETREQUEST']._serialized_start=88
  _globals['_ALGORITHMMANIFESTSCHEMAGETREQUEST']._serialized_end=140
  _globals['_ALGORITHMMANIFESTSCHEMAGETRESPONSE']._serialized_start=142
  _globals['_ALGORITHMMANIFESTSCHEMAGETRESPONSE']._serialized_end=257
  _globals['_ALGORITHMMANIFESTAPI']._serialized_start=259
  _globals['_ALGORITHMMANIFESTAPI']._serialized_end=377
# @@protoc_insertion_point(module_scope)
