# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: aoi_transaction.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'aoi_transaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import aoi_pb2 as aoi__pb2
try:
  common__models__pb2 = aoi__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = aoi__pb2.common_models_pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.aoi_pb2 import *
from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61oi_transaction.proto\x12\x07oi.papi\x1a\taoi.proto\x1a\x13\x63ommon_models.proto\")\n\x1b\x41OITransactionStatusRequest\x12\n\n\x02id\x18\x01 \x01(\t\"a\n\x1c\x41OITransactionStatusResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12,\n\x0btransaction\x18\x02 \x01(\x0b\x32\x17.oi.papi.AOITransaction\"O\n\x18\x41OITransactionGetRequest\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\n\n\x02id\x18\x02 \x01(\t\"\x8a\x01\n\x19\x41OITransactionGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12/\n\x0f\x61oi_identifiers\x18\x03 \x03(\x0b\x32\x16.oi.papi.AOIIdentifier2\xb8\x01\n\x11\x41OITransactionApi\x12L\n\x03get\x12!.oi.papi.AOITransactionGetRequest\x1a\".oi.papi.AOITransactionGetResponse\x12U\n\x06status\x12$.oi.papi.AOITransactionStatusRequest\x1a%.oi.papi.AOITransactionStatusResponseP\x00P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aoi_transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_AOITRANSACTIONSTATUSREQUEST']._serialized_start=66
  _globals['_AOITRANSACTIONSTATUSREQUEST']._serialized_end=107
  _globals['_AOITRANSACTIONSTATUSRESPONSE']._serialized_start=109
  _globals['_AOITRANSACTIONSTATUSRESPONSE']._serialized_end=206
  _globals['_AOITRANSACTIONGETREQUEST']._serialized_start=208
  _globals['_AOITRANSACTIONGETREQUEST']._serialized_end=287
  _globals['_AOITRANSACTIONGETRESPONSE']._serialized_start=290
  _globals['_AOITRANSACTIONGETRESPONSE']._serialized_end=428
  _globals['_AOITRANSACTIONAPI']._serialized_start=431
  _globals['_AOITRANSACTIONAPI']._serialized_end=615
# @@protoc_insertion_point(module_scope)
