# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: resource.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'resource.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import subject_pb2 as subject__pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.subject_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eresource.proto\x12\x12oi.papi.permission\x1a\x13\x63ommon_models.proto\x1a\rsubject.proto\"+\n\x1bResourceRegisterTypeRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\"[\n\x1cResourceRegisterTypeResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\r\x12\x17\n\x0f\x61lready_existed\x18\x03 \x01(\x08\"F\n\x18ResourceTypesListRequest\x12\r\n\x05value\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05regex\x18\x03 \x01(\x08\"\xa3\x01\n\x19ResourceTypesListResponse\x12S\n\x0ctype_to_name\x18\x01 \x03(\x0b\x32=.oi.papi.permission.ResourceTypesListResponse.TypeToNameEntry\x1a\x31\n\x0fTypeToNameEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb4\x03\n\x08Resource\x12\n\n\x02id\x18\x01 \x01(\t\x12/\n\x04type\x18\x02 \x01(\x0e\x32!.oi.papi.permission.Resource.Type\"\xea\x02\n\x04Type\x12$\n PERMISSION_RESOURCE_TYPE_UNKNOWN\x10\x00\x12\r\n\tALGORITHM\x10\x01\x12\x19\n\x15\x41LGORITHM_COMPUTATION\x10\x02\x12\x14\n\x10\x41LGORITHM_CONFIG\x10\x03\x12\x0c\n\x08\x41NALYSIS\x10\x04\x12\x18\n\x14\x41NALYSIS_COMPUTATION\x10\x05\x12\x13\n\x0f\x41NALYSIS_CONFIG\x10\x06\x12\x12\n\x0e\x41OI_COLLECTION\x10\x07\x12\n\n\x06RESULT\x10\x08\x12\x07\n\x03TOI\x10\t\x12\x17\n\x12\x44IRECT_RANGE_START\x10\xe8\x07\x12\x10\n\x0b\x44\x41TA_SOURCE\x10\xf2\x07\x12\x11\n\x0c\x44\x41TA_SOURCES\x10\xf3\x07\x12\x1c\n\x17\x41PPLICATION_RANGE_START\x10\xd0\x0f\x12\x1a\n\x15MOBILE_WORKFORCE_TASK\x10\xb4\x10\x12\x1e\n\x19MOBILE_WORKFORCE_CAMPAIGN\x10\xb5\x10\"v\n\x15ResourceCreateRequest\x12/\n\tresources\x18\x01 \x03(\x0b\x32\x1c.oi.papi.permission.Resource\x12,\n\x06parent\x18\x02 \x01(\x0b\x32\x1c.oi.papi.permission.Resource\"o\n\x16ResourceCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12/\n\tresources\x18\x02 \x03(\x0b\x32\x1c.oi.papi.permission.Resource\x12\x0f\n\x07message\x18\x03 \x01(\t\"\xbc\x01\n\x13ResourceListRequest\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.oi.papi.permission.Resource.Type\x12\x18\n\x10permission_types\x18\x02 \x03(\r\x12,\n\x06parent\x18\x03 \x01(\x0b\x32\x1c.oi.papi.permission.Resource\x12,\n\x07subject\x18\x04 \x01(\x0b\x32\x1b.oi.papi.permission.Subject\"\\\n\x14ResourceListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12/\n\tresources\x18\x02 \x03(\x0b\x32\x1c.oi.papi.permission.Resource2\xa3\x03\n\x0bResourceApi\x12m\n\x08register\x12/.oi.papi.permission.ResourceRegisterTypeRequest\x1a\x30.oi.papi.permission.ResourceRegisterTypeResponse\x12_\n\x06\x63reate\x12).oi.papi.permission.ResourceCreateRequest\x1a*.oi.papi.permission.ResourceCreateResponse\x12Y\n\x04list\x12\'.oi.papi.permission.ResourceListRequest\x1a(.oi.papi.permission.ResourceListResponse\x12i\n\nlist_types\x12,.oi.papi.permission.ResourceTypesListRequest\x1a-.oi.papi.permission.ResourceTypesListResponseP\x00P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'resource_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_RESOURCETYPESLISTRESPONSE_TYPETONAMEENTRY']._loaded_options = None
  _globals['_RESOURCETYPESLISTRESPONSE_TYPETONAMEENTRY']._serialized_options = b'8\001'
  _globals['_RESOURCEREGISTERTYPEREQUEST']._serialized_start=74
  _globals['_RESOURCEREGISTERTYPEREQUEST']._serialized_end=117
  _globals['_RESOURCEREGISTERTYPERESPONSE']._serialized_start=119
  _globals['_RESOURCEREGISTERTYPERESPONSE']._serialized_end=210
  _globals['_RESOURCETYPESLISTREQUEST']._serialized_start=212
  _globals['_RESOURCETYPESLISTREQUEST']._serialized_end=282
  _globals['_RESOURCETYPESLISTRESPONSE']._serialized_start=285
  _globals['_RESOURCETYPESLISTRESPONSE']._serialized_end=448
  _globals['_RESOURCETYPESLISTRESPONSE_TYPETONAMEENTRY']._serialized_start=399
  _globals['_RESOURCETYPESLISTRESPONSE_TYPETONAMEENTRY']._serialized_end=448
  _globals['_RESOURCE']._serialized_start=451
  _globals['_RESOURCE']._serialized_end=887
  _globals['_RESOURCE_TYPE']._serialized_start=525
  _globals['_RESOURCE_TYPE']._serialized_end=887
  _globals['_RESOURCECREATEREQUEST']._serialized_start=889
  _globals['_RESOURCECREATEREQUEST']._serialized_end=1007
  _globals['_RESOURCECREATERESPONSE']._serialized_start=1009
  _globals['_RESOURCECREATERESPONSE']._serialized_end=1120
  _globals['_RESOURCELISTREQUEST']._serialized_start=1123
  _globals['_RESOURCELISTREQUEST']._serialized_end=1311
  _globals['_RESOURCELISTRESPONSE']._serialized_start=1313
  _globals['_RESOURCELISTRESPONSE']._serialized_end=1405
  _globals['_RESOURCEAPI']._serialized_start=1408
  _globals['_RESOURCEAPI']._serialized_end=1827
# @@protoc_insertion_point(module_scope)
