# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: provider_quotas.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'provider_quotas.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15provider_quotas.proto\x12\x0eoi.papi.quotas\"-\n\x19ProviderQuotasListRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\"f\n\rProviderQuota\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x12\n\nquota_name\x18\x02 \x01(\t\x12\x0c\n\x04used\x18\x03 \x01(\x02\x12\r\n\x05limit\x18\x04 \x01(\x02\x12\x0c\n\x04unit\x18\x05 \x01(\t\"K\n\x1aProviderQuotasListResponse\x12-\n\x06quotas\x18\x01 \x03(\x0b\x32\x1d.oi.papi.quotas.ProviderQuota2r\n\x11ProviderQuotasApi\x12]\n\x04list\x12).oi.papi.quotas.ProviderQuotasListRequest\x1a*.oi.papi.quotas.ProviderQuotasListResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'provider_quotas_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PROVIDERQUOTASLISTREQUEST']._serialized_start=41
  _globals['_PROVIDERQUOTASLISTREQUEST']._serialized_end=86
  _globals['_PROVIDERQUOTA']._serialized_start=88
  _globals['_PROVIDERQUOTA']._serialized_end=190
  _globals['_PROVIDERQUOTASLISTRESPONSE']._serialized_start=192
  _globals['_PROVIDERQUOTASLISTRESPONSE']._serialized_end=267
  _globals['_PROVIDERQUOTASAPI']._serialized_start=269
  _globals['_PROVIDERQUOTASAPI']._serialized_end=383
# @@protoc_insertion_point(module_scope)
