# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: permission.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'permission.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import resource_pb2 as resource__pb2
try:
  common__models__pb2 = resource__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = resource__pb2.common_models_pb2
try:
  subject__pb2 = resource__pb2.subject__pb2
except AttributeError:
  subject__pb2 = resource__pb2.subject_pb2
from terrascope_api.models import subject_pb2 as subject__pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.resource_pb2 import *
from terrascope_api.models.subject_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10permission.proto\x12\x12oi.papi.permission\x1a\x13\x63ommon_models.proto\x1a\x0eresource.proto\x1a\rsubject.proto\"\x9c\x02\n\nPermission\x12-\n\x08subjects\x18\x03 \x03(\x0b\x32\x1b.oi.papi.permission.Subject\x12=\n\x10permission_types\x18\x04 \x03(\x0e\x32#.oi.papi.permission.Permission.Type\x12/\n\tresources\x18\x05 \x03(\x0b\x32\x1c.oi.papi.permission.Resource\"o\n\x04Type\x12\x1b\n\x17PERMISSION_TYPE_UNKNOWN\x10\x00\x12\x08\n\x04READ\x10\x01\x12\t\n\x05WRITE\x10\x02\x12\t\n\x05\x41\x44MIN\x10\x03\x12\x0b\n\x07\x45XECUTE\x10\x04\x12\t\n\x05ORDER\x10\x05\x12\x12\n\x0eORDER_APPROVER\x10\x06\"N\n\x17PermissionCreateRequest\x12\x33\n\x0bpermissions\x18\x01 \x03(\x0b\x32\x1e.oi.papi.permission.Permission\"@\n\x18PermissionCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x0f\n\x07message\x18\x02 \x01(\t\"N\n\x17PermissionDeleteRequest\x12\x33\n\x0bpermissions\x18\x01 \x03(\x0b\x32\x1e.oi.papi.permission.Permission\"@\n\x18PermissionDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xb3\x01\n\x14PermissionGetRequest\x12/\n\tresources\x18\x01 \x03(\x0b\x32\x1c.oi.papi.permission.Resource\x12<\n\x0fpermission_type\x18\x02 \x01(\x0e\x32#.oi.papi.permission.Permission.Type\x12,\n\x07subject\x18\x03 \x01(\x0b\x32\x1b.oi.papi.permission.Subject\",\n\x15PermissionGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"\xb5\x01\n\x15PermissionListRequest\x12/\n\tresources\x18\x01 \x03(\x0b\x32\x1c.oi.papi.permission.Resource\x12=\n\x10permission_types\x18\x02 \x03(\x0e\x32#.oi.papi.permission.Permission.Type\x12,\n\x07subject\x18\x03 \x01(\x0b\x32\x1b.oi.papi.permission.Subject\"\x7f\n\x0ePermissionList\x12<\n\x0fpermission_type\x18\x01 \x01(\x0e\x32#.oi.papi.permission.Permission.Type\x12/\n\tresources\x18\x02 \x03(\x0b\x32\x1c.oi.papi.permission.Resource\"s\n\x16PermissionListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x44\n\x18permission_and_resources\x18\x02 \x03(\x0b\x32\".oi.papi.permission.PermissionList\"\xde\x04\n\x18PermissionSystemMetadata\x12\x62\n\x17resource_types_metadata\x18\x01 \x03(\x0b\x32\x41.oi.papi.permission.PermissionSystemMetadata.ResourceTypeMetadata\x12\x66\n\x19permission_types_metadata\x18\x02 \x03(\x0b\x32\x43.oi.papi.permission.PermissionSystemMetadata.PermissionTypeMetadata\x12]\n\x14resource_permissions\x18\x03 \x03(\x0b\x32?.oi.papi.permission.PermissionSystemMetadata.ResourcePermission\x1a\\\n\x14ResourceTypeMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0b\n\x03ord\x18\x04 \x01(\x05\x1a^\n\x16PermissionTypeMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0b\n\x03ord\x18\x04 \x01(\x05\x1aY\n\x12ResourcePermission\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x17\n\x0fpermission_type\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"\x1e\n\x1cPermissionGetMetadataRequest\"t\n\x1dPermissionGetMetadataResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12>\n\x08metadata\x18\x02 \x01(\x0b\x32,.oi.papi.permission.PermissionSystemMetadata2\x89\x04\n\rPermissionApi\x12\x63\n\x06\x63reate\x12+.oi.papi.permission.PermissionCreateRequest\x1a,.oi.papi.permission.PermissionCreateResponse\x12\x63\n\x06\x64\x65lete\x12+.oi.papi.permission.PermissionDeleteRequest\x1a,.oi.papi.permission.PermissionDeleteResponse\x12Z\n\x03get\x12(.oi.papi.permission.PermissionGetRequest\x1a).oi.papi.permission.PermissionGetResponse\x12]\n\x04list\x12).oi.papi.permission.PermissionListRequest\x1a*.oi.papi.permission.PermissionListResponse\x12s\n\x0cget_metadata\x12\x30.oi.papi.permission.PermissionGetMetadataRequest\x1a\x31.oi.papi.permission.PermissionGetMetadataResponseP\x00P\x01P\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'permission_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PERMISSION']._serialized_start=93
  _globals['_PERMISSION']._serialized_end=377
  _globals['_PERMISSION_TYPE']._serialized_start=266
  _globals['_PERMISSION_TYPE']._serialized_end=377
  _globals['_PERMISSIONCREATEREQUEST']._serialized_start=379
  _globals['_PERMISSIONCREATEREQUEST']._serialized_end=457
  _globals['_PERMISSIONCREATERESPONSE']._serialized_start=459
  _globals['_PERMISSIONCREATERESPONSE']._serialized_end=523
  _globals['_PERMISSIONDELETEREQUEST']._serialized_start=525
  _globals['_PERMISSIONDELETEREQUEST']._serialized_end=603
  _globals['_PERMISSIONDELETERESPONSE']._serialized_start=605
  _globals['_PERMISSIONDELETERESPONSE']._serialized_end=669
  _globals['_PERMISSIONGETREQUEST']._serialized_start=672
  _globals['_PERMISSIONGETREQUEST']._serialized_end=851
  _globals['_PERMISSIONGETRESPONSE']._serialized_start=853
  _globals['_PERMISSIONGETRESPONSE']._serialized_end=897
  _globals['_PERMISSIONLISTREQUEST']._serialized_start=900
  _globals['_PERMISSIONLISTREQUEST']._serialized_end=1081
  _globals['_PERMISSIONLIST']._serialized_start=1083
  _globals['_PERMISSIONLIST']._serialized_end=1210
  _globals['_PERMISSIONLISTRESPONSE']._serialized_start=1212
  _globals['_PERMISSIONLISTRESPONSE']._serialized_end=1327
  _globals['_PERMISSIONSYSTEMMETADATA']._serialized_start=1330
  _globals['_PERMISSIONSYSTEMMETADATA']._serialized_end=1936
  _globals['_PERMISSIONSYSTEMMETADATA_RESOURCETYPEMETADATA']._serialized_start=1657
  _globals['_PERMISSIONSYSTEMMETADATA_RESOURCETYPEMETADATA']._serialized_end=1749
  _globals['_PERMISSIONSYSTEMMETADATA_PERMISSIONTYPEMETADATA']._serialized_start=1751
  _globals['_PERMISSIONSYSTEMMETADATA_PERMISSIONTYPEMETADATA']._serialized_end=1845
  _globals['_PERMISSIONSYSTEMMETADATA_RESOURCEPERMISSION']._serialized_start=1847
  _globals['_PERMISSIONSYSTEMMETADATA_RESOURCEPERMISSION']._serialized_end=1936
  _globals['_PERMISSIONGETMETADATAREQUEST']._serialized_start=1938
  _globals['_PERMISSIONGETMETADATAREQUEST']._serialized_end=1968
  _globals['_PERMISSIONGETMETADATARESPONSE']._serialized_start=1970
  _globals['_PERMISSIONGETMETADATARESPONSE']._serialized_end=2086
  _globals['_PERMISSIONAPI']._serialized_start=2089
  _globals['_PERMISSIONAPI']._serialized_end=2610
# @@protoc_insertion_point(module_scope)
