# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: project_filter.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'project_filter.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import filter_pb2 as filter__pb2
try:
  common__models__pb2 = filter__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = filter__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.filter_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14project_filter.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\x1a\x0c\x66ilter.proto\"s\n\rProjectFilter\x12\x1f\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x0f.oi.papi.Filter\x12\x1a\n\x12\x61nalysis_config_id\x18\x02 \x01(\t\x12\x11\n\tnode_name\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x05 \x01(\t\"T\n!ProjectFilterMappingCreateRequest\x12/\n\x0fproject_filters\x18\x01 \x03(\x0b\x32\x16.oi.papi.ProjectFilter\"9\n\"ProjectFilterMappingCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"T\n!ProjectFilterMappingDeleteRequest\x12/\n\x0fproject_filters\x18\x01 \x03(\x0b\x32\x16.oi.papi.ProjectFilter\"9\n\"ProjectFilterMappingDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xe8\x01\n\x10ProjectFilterApi\x12i\n\x0e\x63reate_mapping\x12*.oi.papi.ProjectFilterMappingCreateRequest\x1a+.oi.papi.ProjectFilterMappingCreateResponse\x12i\n\x0e\x64\x65lete_mapping\x12*.oi.papi.ProjectFilterMappingDeleteRequest\x1a+.oi.papi.ProjectFilterMappingDeleteResponseP\x00P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'project_filter_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PROJECTFILTER']._serialized_start=68
  _globals['_PROJECTFILTER']._serialized_end=183
  _globals['_PROJECTFILTERMAPPINGCREATEREQUEST']._serialized_start=185
  _globals['_PROJECTFILTERMAPPINGCREATEREQUEST']._serialized_end=269
  _globals['_PROJECTFILTERMAPPINGCREATERESPONSE']._serialized_start=271
  _globals['_PROJECTFILTERMAPPINGCREATERESPONSE']._serialized_end=328
  _globals['_PROJECTFILTERMAPPINGDELETEREQUEST']._serialized_start=330
  _globals['_PROJECTFILTERMAPPINGDELETEREQUEST']._serialized_end=414
  _globals['_PROJECTFILTERMAPPINGDELETERESPONSE']._serialized_start=416
  _globals['_PROJECTFILTERMAPPINGDELETERESPONSE']._serialized_end=473
  _globals['_PROJECTFILTERAPI']._serialized_start=476
  _globals['_PROJECTFILTERAPI']._serialized_end=708
# @@protoc_insertion_point(module_scope)
