# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: forgot_password.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'forgot_password.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x66orgot_password.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\"/\n\x19UserForgotPasswordRequest\x12\x12\n\nuser_email\x18\x01 \x01(\t\"1\n\x1aUserForgotPasswordResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2o\n\x11\x46orgotPasswordApi\x12Z\n\x0f\x66orgot_password\x12\".oi.papi.UserForgotPasswordRequest\x1a#.oi.papi.UserForgotPasswordResponseP\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'forgot_password_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_USERFORGOTPASSWORDREQUEST']._serialized_start=55
  _globals['_USERFORGOTPASSWORDREQUEST']._serialized_end=102
  _globals['_USERFORGOTPASSWORDRESPONSE']._serialized_start=104
  _globals['_USERFORGOTPASSWORDRESPONSE']._serialized_end=153
  _globals['_FORGOTPASSWORDAPI']._serialized_start=155
  _globals['_FORGOTPASSWORDAPI']._serialized_end=266
# @@protoc_insertion_point(module_scope)
